User manual
===========

This manual attempts to cover every part of Photini in detail, but still be usable as a tutorial.
I suggest you read the :doc:`image_selector` section first, then read other sections when you start using the relevant features.

.. toctree::
   :maxdepth: 2

   image_selector
   descriptive_metadata
   technical_metadata
   map
   flickr
   picasa
   importer
   configuration
   tags
